=======
History
=======

0.1.0 (2019-04-12)
------------------

* First release on PyPI.

0.1.1 (2019-04-12)
------------------

* corrected home page

0.1.2 (2019-04-14)
------------------

* various doc and badges adjustments

0.1.4 (2019-04-14)
------------------

* various doc and badges adjustments

0.1.6 (2019-04-15)
------------------

* fixed packaging errors for README and version


0.2.0 (2019-04-16)
------------------

* added `pipstripper` cli mode.
* swapped --scan option for the more explicit --noscan
* added more docstrings
* README.md changes
  
0.3.0 (2019-04-22)
------------------
* generating `requirements.txt` instead of `requirements.dev.txt`
* improved pip package name to python import name matching, using `Module.pkg_resources`.
* README.md changes
* adjustments to argparse help text
